function RGBd=HLG_EOTF(RGBs, Lw, Lb)
% maps the non-linear HLG signal (RGBs) into display light (RGBd)
  
  %setup defaults for Lw, Lb if not provided
  if (nargin<2)
    Lw = 800;
  end 
  if (nargin<3)
    Lb = 50;
  end
     
  %clip rgb
  RGBs(RGBs<0)=0;
  
  %define constants for inverse OETF
  a=0.17883277;
  b=1-4*a;
  c=0.5-a*log(4*a);
  
  %apply inverse OETF
  Ergb=zeros(size(RGBs));
  idx=RGBs<=0.5;
  Ergb(idx) = (RGBs(idx).^2)./3;
  Ergb(~idx) = (exp((RGBs(~idx)-c)./a)+b)/12;
  
  %define constants for OOTF
  Ys= [0.2627 0.6780 0.0593] * Ergb;
  alpha = (Lw - Lb);
  beta = Lb;
  if Lw<=1000
    gamma = 1.2;
  else
    gamma = 1.2 + 0.42*log10(Lw/1000);
  end
  
  %apply OOTF
  RGBd = ([1;1;1]*(alpha.*Ys.^gamma)).*Ergb + beta;
     
end
