function RGBs = HLG_invEOTF(RGBd, Lw, Lb)
%maps the display light (RGBd) into non-linear HLG signal (RGBs)

  %setup defaults for Lw, Lb if not provided
  if (nargin<2)
    Lw = 800;
  end 
  if (nargin<3)
    Lb = 50;
  end
   
  %define constants for inverse OOTF
  Yd = [0.2627 0.6780 0.0593] * RGBd;
  alpha = (Lw - Lb);
  beta = Lb;
  if Lw<=1000
    gamma = 1.2;
  else
    gamma = 1.2 + 0.42*log10(Lw/1000);
  end
  s = ((Yd-beta)/alpha).^((1-gamma)/gamma);

  %apply inverse OOTF
  Ergb = ([1;1;1]*s).*(RGBd - beta)./alpha;
  
  %clip negative results
  Ergb(Ergb<0)=0;
  
  %define constants for inverse OETF
  a=0.17883277;
  b=1-4*a;
  c=0.5-a*log(4*a);
  
  RGBs = zeros(size(Ergb));
  idx = Ergb<=1/12;
  RGBs(idx) = sqrt(3*Ergb(idx));
  RGBs(~idx) = a.*log(12*Ergb(~idx)-b)+c;
  
end
